Map

Struct Map 

pub struct Map<T: Handled> {
    value_by_id: HashMap<Id, T>,
    id_by_handle: HashMap<Handle, Id>,
}

Fields

value_by_id: HashMap<Id, T>id_by_handle: HashMap<Handle, Id>

Implementations

Source

impl<T: Handled> Map<T>

pub fn get<Q>(&self, k: &Q) -> Option<&T>
where Q: AsHandleOrId,

pub fn insert_new(&mut self, value: T) -> Option<HandleOrId>

Inserts value into Map unless its id or one of its handles is already present in the map. In that case the id or one of the conflicting handles is returned.

pub fn values(&self) -> Values<'_, Id, T>

Returns an Iterator over the values of this map.