pub struct Map<T: Handled> {
value_by_id: HashMap<Id, T>,
id_by_handle: HashMap<Handle, Id>,
}Fields
value_by_id: HashMap<Id, T>id_by_handle: HashMap<Handle, Id>Implementations
Sourceimpl<T: Handled> Map<T>
impl<T: Handled> Map<T>
pub fn get<Q>(&self, k: &Q) -> Option<&T>where
Q: AsHandleOrId,
Sourcepub fn insert_new(&mut self, value: T) -> Option<HandleOrId>
pub fn insert_new(&mut self, value: T) -> Option<HandleOrId>
Inserts value into Map unless its id or one of its handles is already
present in the map. In that case the id or one of the conflicting handles is returned.